@@ -10,6 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from neutron_lib import constants
+
+
 KNOWN_ATTRIBUTES = (
     'admin_state_up',
     'allocation_pools',
@@ -38,7 +41,7 @@ KNOWN_ATTRIBUTES = (
     'prefixes',
     'prefixlen',
     'project_id',
-    'shared',
+    constants.SHARED,
     'status',
     'subnets',
     'subnetpool_id',
@@ -87,7 +90,9 @@ KNOWN_EXTENSIONS = (
     'external-net',
     'extra_dhcp_opt',
     'extraroute',
+    'fip-port-details',
     'flavors',
+    'ip-substring-filtering',
     'l3-ha',
     'l3_agent_scheduler',
     'logging',
@@ -106,6 +111,7 @@ KNOWN_EXTENSIONS = (
     'router',
     'router_availability_zone',
     'security-group',
+    'segment',
     'service-type',
     'sorting',
     'standard-attr-description',
@@ -113,6 +119,7 @@ KNOWN_EXTENSIONS = (
     'standard-attr-timestamp',
     'subnet_allocation',
     'subnet_onboard',
+    'subnet-segmentid-writable',
     'tag',
     'trunk',
     'trunk-details',
@@ -126,6 +133,11 @@ KNOWN_EXTENSIONS = (
     'bgpvpn',  # https://git.openstack.org/cgit/openstack/networking-bgpvpn
     'bgpvpn-routes-control',
     'bgpvpn-vni',
+
+    # git.openstack.org/cgit/openstack/neutron-vpnaas
+    'vpnaas',
+    'vpn-endpoint-groups',
+    'vpn-flavors',
 )
 
 KNOWN_KEYWORDS = (
@@ -135,8 +147,12 @@ KNOWN_KEYWORDS = (
     'convert_list_to',
     'default',
     'enforce_policy',
+    'is_filter',
+    'is_sort_key',
     'is_visible',
     'primary_key',
     'required_by_policy',
     'validate',
+    'default_overrides_none',
+    'dict_populate_defaults',
 )
