@@ -14,9 +14,8 @@
 
 from neutron_lib.api import converters
 from neutron_lib.api.definitions import l3
+from neutron_lib.db import constants as db_const
 
-# Regular expression to validate an empty string
-EMPTY_REGEX = (r'^$')
 # Regular expression to validate 32 bits unsigned int
 UINT32_REGEX = (r'(0|[1-9]\d{0,8}|[1-3]\d{9}|4[01]\d{8}|42[0-8]\d{7}'
                 r'|429[0-3]\d{6}|4294[0-8]\d{5}|42949[0-5]\d{4}'
@@ -33,14 +32,12 @@ IP4_REGEX = (r'(%s\.%s\.%s\.%s)') % (UINT8_REGEX, UINT8_REGEX, UINT8_REGEX,
 # Regular expression to validate Route Target list format
 # Support of the Type 0, Type 1 and Type 2, cf. chapter 4.2 in RFC 4364
 # Also validates Route Distinguisher list format
-RTRD_REGEX = (r'%s|^(%s:%s|%s:%s|%s:%s)$') % (EMPTY_REGEX, UINT16_REGEX,
-                                              UINT32_REGEX, IP4_REGEX,
-                                              UINT16_REGEX, UINT32_REGEX,
-                                              UINT16_REGEX)
+RTRD_REGEX = (r'^(%s:%s|%s:%s|%s:%s)$') % (UINT16_REGEX, UINT32_REGEX,
+                                           IP4_REGEX, UINT16_REGEX,
+                                           UINT32_REGEX, UINT16_REGEX)
 
 # The alias of the extension.
 ALIAS = 'bgpvpn'
-LABEL = 'BGPVPN'
 
 # Whether or not this extension is simply signaling behavior to the user
 # or it actively modifies the attribute map.
@@ -84,13 +81,14 @@ RESOURCE_ATTRIBUTE_MAP = {
                'primary_key': True,
                'enforce_policy': True},
         'tenant_id': {'allow_post': True, 'allow_put': False,
-                      'validate': {'type:string': None},
+                      'validate': {
+                          'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                       'required_by_policy': True,
                       'is_visible': True,
                       'enforce_policy': True},
         'name': {'allow_post': True, 'allow_put': True,
                  'default': '',
-                 'validate': {'type:string': None},
+                 'validate': {'type:string': db_const.NAME_FIELD_SIZE},
                  'is_visible': True,
                  'enforce_policy': True},
         'type': {'allow_post': True, 'allow_put': False,
@@ -145,7 +143,8 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
                    'is_visible': True,
                    'primary_key': True},
             'tenant_id': {'allow_post': True, 'allow_put': False,
-                          'validate': {'type:string': None},
+                          'validate': {
+                              'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                           'required_by_policy': True,
                           'is_visible': True,
                           'enforce_policy': True},
@@ -164,7 +163,8 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
                    'is_visible': True,
                    'primary_key': True},
             'tenant_id': {'allow_post': True, 'allow_put': False,
-                          'validate': {'type:string': None},
+                          'validate': {
+                              'type:string': db_const.PROJECT_ID_FIELD_SIZE},
                           'required_by_policy': True,
                           'is_visible': True,
                           'enforce_policy': True},
