@@ -87,10 +87,6 @@ VIF_TYPE_BINDING_FAILED = 'binding_failed'
 VIF_TYPE_DISTRIBUTED = 'distributed'
 VIF_TYPE_OVS = 'ovs'
 VIF_TYPE_BRIDGE = 'bridge'
-# - ovs-acceleration: The ovs acceleration interface type is a SR-IOV hostdev
-#                     interface which support switchdev mode provided by
-#                     kernel 4.8.
-VIF_TYPE_OVS_ACCELERATION = 'ovs_acceleration'
 VIF_TYPE_OTHER = 'other'
 VIF_TYPE_TAP = 'tap'
 # vif_type_macvtap: Tells Nova that the macvtap vif_driver should be used to
@@ -124,10 +120,6 @@ VNIC_TYPES = [VNIC_NORMAL, VNIC_DIRECT, VNIC_MACVTAP, VNIC_BAREMETAL,
 # The alias of the extension.
 ALIAS = 'binding'
 
-# The label to lookup the plugin in the plugin directory. It can match the
-# alias, as required.
-LABEL = 'binding'
-
 # Whether or not this extension is simply signaling behavior to the user
 # or it actively modifies the attribute map.
 IS_SHIM_EXTENSION = False
