@@ -681,6 +681,18 @@ def validate_subnet_list(data, valid_values=None):
     return _validate_subnet_list(data, valid_values)
 
 
+def validate_subnet_list_or_none(data, key_specs=None):
+    """Validate data is a list of subnet dicts or None.
+
+    :param data: The data to validate.
+    :param key_specs: Not used!
+    :returns: None if data is None or a valid list of subnet dicts, otherwise
+        a human readable message as to why the data is invalid.
+    """
+    if data is not None:
+        return validate_subnet_list(data, key_specs)
+
+
 def validate_regex(data, valid_values=None):
     """Validate data is matched against a regex.
 
@@ -793,29 +805,39 @@ def validate_uuid_list(data, valid_values=None):
     return _validate_uuid_list(data, valid_values)
 
 
+def _extract_validator(key_validator):
+    # Find validator function in key validation spec
+    #
+    # TODO(salv-orlando): Structure of dict attributes should be improved
+    # to avoid iterating over items
+    for (k, v) in key_validator.items():
+        if k.startswith('type:'):
+            (validator_name, validator_params) = (k, v)
+            try:
+                return (validator_name,
+                        validators[validator_name],
+                        validator_params)
+            except KeyError:
+                raise UndefinedValidator(validator_name)
+    return None, None, None
+
+
 def _validate_dict_item(key, key_validator, data):
     # Find conversion function, if any, and apply it
     conv_func = key_validator.get('convert_to')
     if conv_func:
         data[key] = conv_func(data.get(key))
-    # Find validator function
-    # TODO(salv-orlando): Structure of dict attributes should be improved
-    # to avoid iterating over items
-    val_func = val_params = None
-    for (k, v) in key_validator.items():
-        if k.startswith('type:'):
-            # ask forgiveness, not permission
-            try:
-                val_func = validators[k]
-            except KeyError:
-                msg = _("Validator '%s' does not exist.") % k
-                LOG.debug(msg)
-                return msg
-            val_params = v
-            break
-    # Process validation
-    if val_func:
-        return val_func(data.get(key), val_params)
+    try:
+        dummy_, val_func, val_params = _extract_validator(key_validator)
+        if val_func:
+            return val_func(data.get(key), val_params)
+        # NOTE(tmorin): here we silently omit to validate a key for which
+        # no type validator has been defined
+    except UndefinedValidator as e:
+        # NOTE(tmorin): Should we really return an API error on such
+        # an issue. Wouldn't InternalServer error be more natural ?
+        LOG.debug(e.message)
+        return e.message
 
 
 def validate_dict(data, key_specs=None):
@@ -938,21 +960,21 @@ def validate_port_range_or_none(data, valid_values=None):
     data = str(data)
     ports = data.split(':')
     if len(ports) > 2:
-        msg = _("Port range must be two integers separated by a colon.")
+        msg = _("Port range must be two integers separated by a colon")
         LOG.debug(msg)
         return msg
     for p in ports:
         if len(p) == 0:
-            msg = _("Port range must be two integers separated by a colon.")
+            msg = _("Port range must be two integers separated by a colon")
             LOG.debug(msg)
             return msg
         if not netutils.is_valid_port(p):
-            msg = _("Invalid port: %s.") % p
+            msg = _("Invalid port: %s") % p
             LOG.debug(msg)
             return msg
-    if len(ports) > 1 and ports[0] > ports[1]:
+    if len(ports) > 1 and int(ports[0]) > int(ports[1]):
         msg = _("First port in a port range must be lower than the second "
-                "port.")
+                "port")
         LOG.debug(msg)
         return msg
 
@@ -1001,7 +1023,8 @@ def validate_subports(data, valid_values=None):
         if segmentation_type == 'inherit':
             return
         segmentation_id = subport.get("segmentation_id")
-        if (not segmentation_type or not segmentation_id) and len(subport) > 1:
+        if ((not segmentation_type or segmentation_id is None) and
+                len(subport) > 1):
             msg = _("Invalid subport details '%s': missing segmentation "
                     "information. Must specify both segmentation_id and "
                     "segmentation_type") % subport
@@ -1013,7 +1036,7 @@ def validate_subports(data, valid_values=None):
                                  "subport": subport["port_id"]}
             LOG.debug(msg)
             return msg
-        if segmentation_id:
+        if segmentation_id is not None:
             segmentations[segmentation_type].add(segmentation_id)
 
 
@@ -1072,7 +1095,16 @@ validators = {'type:dict': validate_dict,
               'type:list_of_unique_strings': validate_list_of_unique_strings,
               'type:list_of_any_key_specs_or_none':
                   validate_any_key_specs_or_none,
-              'type:service_plugin_type': validate_service_plugin_type}
+              'type:service_plugin_type': validate_service_plugin_type,
+              'type:list_of_subnets_or_none': validate_subnet_list_or_none,
+              }
+
+
+class UndefinedValidator(Exception):
+
+    def __init__(self, validator_name):
+        self.validator_name = validator_name
+        self.message = _("Validator '%s' does not exist") % self.validator_name
 
 
 def _to_validation_type(validation_type):
